@@ -9,6 +9,7 @@
 
 import pandas as pd
 import copy
+from tabulate import tabulate
 
 class DMUU:
     """
@@ -240,4 +241,11 @@ class DMUU:
 
         return dmuu_criteria_list
 
+    def pretty_decision(self, tablefmt='psql'):
+        return tabulate(self.decision, headers='keys', tablefmt=tablefmt)
 
+    def pretty_calc(self, tablefmt='psql'):
+        return tabulate(self.df_calc, headers='keys', tablefmt=tablefmt)
+
+    def pretty_original(self, tablefmt='psql'):
+        return tabulate(self.df_original, headers='keys', tablefmt=tablefmt)
