@@ -24,9 +24,6 @@ class MCDA:
         self.normalization_method = None
         self.df_normalized = 0
         self.df_weighted = 0
-        self.df_pis = []
-        self.df_nis = []
-        self.df_closeness = 0
         self.df_decision = []
 
     def dataframe(self, alt_data, alt_labels=[], criteria_label=[]):
@@ -172,36 +169,6 @@ class MCDA:
         else:
             raise ValueError("Invalid signals! It's must be a list of 1 or -1")
 
-    def topsis(self, normalization_method=Vector_):
-        self.__set_normalization_method(normalization_method)      
-        self.__normalize(True)
-        self.__weighting_from_normalized()
-        self.__xis()
-        self.__topsis()
-        return "topsis"
-
-    def wsm(self, normalization_method=None):  
-        self.__set_normalization_method(normalization_method)        
-        self.__normalize()
-        self.__weighting_from_normalized()
-        self.__wsm()
-        return "wsm"
-
-    def wpm(self, normalization_method=None):  
-        self.__set_normalization_method(normalization_method)        
-        self.__normalize()
-        self.__weighting_from_normalized()
-        self.__wpm()
-        return "wsm"
-
-    def waspas(self, lambda_=0.5, normalization_method=None):
-        if self.__check_lambda(lambda_) is True:
-            self.__set_normalization_method(normalization_method)
-            self.__normalize()
-            self.__weighting_from_normalized()
-            self.__waspas(lambda_)
-            return "waspas"
-
     def __set_normalization_method(self, normalization_method):
         if normalization_method in NORMALIZATION_METHODS:
             self.normalization_method = normalization_method 
@@ -223,8 +190,6 @@ class MCDA:
             self.__norm_EnhancedAccuracy(ignore_signals)
         elif self.normalization_method == Logarithmic_:
             self.__norm_Logarithmic(ignore_signals)
-        elif self.normalization_method == TopsisOriginal_:
-            self.__norm_TopsisOriginal()
         else:
             self.df_normalized = self.df_original
 
@@ -387,62 +352,6 @@ class MCDA:
     def __weighting_from_normalized(self):
         weighted = self.df_normalized.iloc[:, 1:] * self.weights
         self.df_weighted = pd.DataFrame(self.df_original.iloc[:,0]).join(weighted)
-         
-    def __xis(self):
-        pis = pd.DataFrame(self.df_weighted.iloc[:, 1:] * self.signals).max(axis=0) * self.signals
-        self.df_pis = pis
-        nis = pd.DataFrame(self.df_weighted.iloc[:, 1:] * self.signals).min(axis=0) * self.signals
-        self.df_nis = nis
-
-    def __topsis(self):
-        dp = np.sqrt(self.df_weighted.iloc[:, 1:].sub(self.df_pis).pow(2).sum(axis=1))
-        dn = np.sqrt(self.df_weighted.iloc[:, 1:].sub(self.df_nis).pow(2).sum(axis=1))
-        closeness = pd.DataFrame(dn.div(dp+dn), columns=["performance score"])
-        i = np.arange(1, len(self.df_original.index)+1, 1)
-        df_concat_labels = pd.DataFrame(self.df_original.iloc[:,0]).join(closeness).sort_values(by=["performance score"], ascending=False, ignore_index=True)
-        df_ranking = df_concat_labels.join(pd.DataFrame(i, columns=["rank"]))
-        self.df_decision = df_ranking
-
-    def __waspas(self, lambda_):
-        w_df = pd.DataFrame(self.df_weighted.iloc[:, 1:])       
-       
-        q_wsm = pd.DataFrame(w_df.sum(axis=1), columns=["WSM"]) * lambda_
-        q_wpm = pd.DataFrame(w_df.prod(axis=1), columns=["WPM"]) * (1 - lambda_) 
-
-        waspas = q_wsm.iloc[:,0] + q_wpm.iloc[:,0]
-        label = "WASPAS (λ " + str(lambda_) + " )" 
-        waspas_df = pd.DataFrame(waspas, columns=[label]) 
-
-        i = np.arange(1, len(self.df_original.index)+1, 1)
-        df_concat_labels = pd.DataFrame(self.df_original.iloc[:,0]).join(waspas_df).sort_values(by=[label], ascending=False, ignore_index=True)
-        df_ranking = df_concat_labels.join(pd.DataFrame(i, columns=["rank"]))
-        
-        self.df_decision = df_ranking
-
-    def __wsm(self):
-        wsm = pd.DataFrame(self.df_weighted.iloc[:, 1:])
-        wsm = pd.DataFrame(wsm.sum(axis=1), columns=["WSM"])
-        i = np.arange(1, len(self.df_original.index)+1, 1)
-        df_concat_labels = pd.DataFrame(self.df_original.iloc[:,0]).join(wsm).sort_values(by=["WSM"], ascending=False, ignore_index=True)
-        df_ranking = df_concat_labels.join(pd.DataFrame(i, columns=["rank"]))
-        self.df_decision = df_ranking
-
-    def __wpm(self):
-        wpm = pd.DataFrame(self.df_weighted.iloc[:, 1:])
-        wpm = pd.DataFrame(wpm.prod(axis=1), columns=["WPM"])
-        i = np.arange(1, len(self.df_original.index)+1, 1)
-        df_concat_labels = pd.DataFrame(self.df_original.iloc[:,0]).join(wpm).sort_values(by=["WPM"], ascending=False, ignore_index=True)
-        df_ranking = df_concat_labels.join(pd.DataFrame(i, columns=["rank"]))
-        self.df_decision = df_ranking
-
-    def __check_lambda(self, lambda_):
-        result = False
-        if type(lambda_) == float:
-            if (lambda_ >= 0 and lambda_ <= 1):
-                result = True
-            else:
-                raise ValueError("Lambda must be a value between 0 and 1!")                
-        return result
 
     def __check_weights(self, weights):
         result = False
