@@ -26,7 +26,7 @@ class TOPSIS(MCDA):
         dn = np.sqrt(self.df_weighted.iloc[:, 1:].sub(self.df_nis).pow(2).sum(axis=1))
         closeness = pd.DataFrame(dn.div(dp+dn), columns=["performance score"])
         i = np.arange(1, len(self.df_original.index)+1, 1)
-        df_concat_labels = pd.DataFrame(self.df_original.iloc[:,0]).join(closeness).sort_values(by=["performance score"], ascending=False, ignore_index=True)
-        df_ranking = df_concat_labels.join(pd.DataFrame(i, columns=["rank"]))
-        self.df_decision = df_ranking
+        df_ranking = pd.DataFrame(self.df_original.iloc[:,0]).join(closeness).sort_values(by=["performance score"], ascending=False)
+        df_ranking["rank"] = i
 
+        self.df_decision = df_ranking.sort_index()
