@@ -23,10 +23,10 @@ class WASPAS(MCDA):
         waspas_df = pd.DataFrame(waspas, columns=[label]) 
 
         i = np.arange(1, len(self.df_original.index)+1, 1)
-        df_concat_labels = pd.DataFrame(self.df_original.iloc[:,0]).join(waspas_df).sort_values(by=[label], ascending=False, ignore_index=True)
-        df_ranking = df_concat_labels.join(pd.DataFrame(i, columns=["rank"]))
-        
-        self.df_decision = df_ranking
+        df_ranking = pd.DataFrame(self.df_original.iloc[:,0]).join(waspas_df).sort_values(by=[label], ascending=False)
+        df_ranking["rank"] = i
+
+        self.df_decision = df_ranking.sort_index()
 
     def __check_lambda(self, lambda_):
         result = False
