@@ -14,8 +14,10 @@ class WPM(MCDA):
     def __wpm(self):
         wpm = pd.DataFrame(self.df_weighted.iloc[:, 1:])
         wpm = pd.DataFrame(wpm.prod(axis=1), columns=["WPM"])
+
         i = np.arange(1, len(self.df_original.index)+1, 1)
-        df_concat_labels = pd.DataFrame(self.df_original.iloc[:,0]).join(wpm).sort_values(by=["WPM"], ascending=False, ignore_index=True)
-        df_ranking = df_concat_labels.join(pd.DataFrame(i, columns=["rank"]))
-        self.df_decision = df_ranking
+        df_ranking = pd.DataFrame(self.df_original.iloc[:,0]).join(wpm).sort_values(by=["WPM"], ascending=False)
+        df_ranking["rank"] = i
+
+        self.df_decision = df_ranking.sort_index()
 
