@@ -15,8 +15,10 @@ class WSM(MCDA):
     def __wsm(self):
         wsm = pd.DataFrame(self.df_weighted.iloc[:, 1:])
         wsm = pd.DataFrame(wsm.sum(axis=1), columns=["WSM"])
+
         i = np.arange(1, len(self.df_original.index)+1, 1)
-        df_concat_labels = pd.DataFrame(self.df_original.iloc[:,0]).join(wsm).sort_values(by=["WSM"], ascending=False, ignore_index=True)
-        df_ranking = df_concat_labels.join(pd.DataFrame(i, columns=["rank"]))
-        self.df_decision = df_ranking
+        df_ranking = pd.DataFrame(self.df_original.iloc[:,0]).join(wsm).sort_values(by=["WSM"], ascending=False)
+        df_ranking["rank"] = i
+
+        self.df_decision = df_ranking.sort_index()
 
